{% extends "base.html" %}
{% block title %}Email project report to {{ project.business }}{% endblock %}

{% block content %}
<h2>Email Project Report to {{ project.business }}</h2>

<form id="project-report-email" action="" method="post" accept-charset="utf-8">
	<table class='vertical'>
		{{ form }}
		<tr>
			<td>&nbsp;</td>
			<td class='submit'>
				<input type='button' value='Cancel' onclick='history.go(-1)' />
				&nbsp;
				<input type='submit' name='submit' value='Save &rarr;' />
			</td>
		</tr>
	</table>
</form>
{% endblock %}
