ul.autocompleter-choices
{
	position: absolute;
	margin: 0;
	padding: 0;
	list-style: none;
	border: 1px solid #7c7c7c;
	border-left-color: #c3c3c3;
	border-right-color: #c3c3c3;
	border-bottom-color: #ddd;
	background-color: #fff;
	text-align: left;
	font-family: Verdana, Geneva, Arial, Helvetica, sans-serif;
	z-index: 50;
	background-color: #fff;
}

ul.autocompleter-choices li
{
	list-style-position: inside;
}
ul.autocompleter-choices li.business
{
	list-style-image: url('../../../images/icons/building.png');
}
ul.autocompleter-choices li.contact
{
	list-style-image: url('../../../images/icons/user.png');
}
ul.autocompleter-choices li.project
{
	list-style-image: url('../../../images/icons/report.png');
}

ul.autocompleter-choices li a {
	color: blue;
	position: relative;
	margin: -2px 0 0 0;
	padding: 0.2em 1.5em 0.2em 0;
	float: none !important; 
	cursor: pointer;
	font-weight: normal;
	white-space: nowrap;
	font-size: 1em;
	line-height: 1.5em;
	width: 100%;
}

ul.autocompleter-choices li.autocompleter-selected
{
	background-color: #EEE;
	width: 100%;
}

ul.autocompleter-choices span.autocompleter-queried
{
	display: inline;
	float: none;
	font-weight: bold;
	margin: 0;
	padding: 0;
}

ul.autocompleter-choices li.autocompleter-selected span.autocompleter-queried
{
	color: #9FCFFF;
}