{% extends "base.html" %}
{% block title %}{% if transaction %}Edit{% else %}Create{% endif %} General Entry{% endblock %}

{% block javascript %}
	{{ form.media|safe }}
{% endblock %}

{% block content %}
<h2>{% if transaction %}Edit{% else %}Create{% endif %} General Entry</h2>
<ul class='header-actions-left'>
	<li><a href='{% url list_accounts %}'>Return to accounts</a></li>
</ul>

<form id="general-entry" action="" method="post" accept-charset="utf-8">
	<table class='vertical'>
		{{ form }}
		<tr>
			<td>&nbsp;</td>
			<td class='submit'>
				<input type='button' value='Cancel' onclick='history.go(-1)' />
				&nbsp;
				<input type='submit' name='submit' value='{% if transaction %}Save{% else %}Create{% endif %} &rarr;' />
			</td>
		</tr>
	</table>
</form>
{% endblock %}
