{% extends "base.html" %}
{% block title %}Email {{ exchange.type }} to {{ exchange.business }}{% endblock %}

{% block content %}
<h2>Email {{ exchange.type }} to {{ exchange.business }}</h2>
<ul>
	<li>Date: {{ exchange.date }}</li>
	<li>Due Date: {{ exchange.date_due }}</li>
	<li>Memo: {{ exchange.memo }}</li>
	<li>Business: {{ exchange.business }}</li>
</ul>
<form id="exchange-email" action="" method="post" accept-charset="utf-8">
	<table class='vertical'>
		{{ form }}
		<tr>
			<td>&nbsp;</td>
			<td class='submit'>
				<input type='button' value='Cancel' onclick='history.go(-1)' />
				&nbsp;
				<input type='submit' name='submit' value='Save &rarr;' />
			</td>
		</tr>
	</table>
</form>
{% endblock %}
