{% extends 'base.html' %}

{% block content %}
<div id="left-panel">
	<div id="inner-left-panel">
		<h2>{{ request.user }}'s hours:</h2>
		<table id='hours' class="crm block_color">
			<tr>
				<th>Current Hours</th>
				<th>Previous Hours</th>
			</tr>
			{% for user, hours in paychecks.items %}
			<tr>
				<td>{{ hours.curr_paychecks_billable}} ({{ hours.curr_paychecks_not_billable}})</td>
				<td>{{ hours.prev_paychecks_billable}} ({{ hours.prev_paychecks_not_billable}})</td>
			</tr>
			{% endfor %}
		</table>
	</div>
</div>
<div id="right-panel">
	<div id="inner-right-panel">
		<img src='{{ graph_url }}' />
	</div>
</div>
{% endblock %}
