{% extends "base.html" %}
{% block title %}Edit {{ exchange.type }}{% endblock %}

{% block content %}
<h2>Edit {{ exchange.type }}</h2>
<p>Use this form to change the type of an exchange (e.g. Purchase to Order).</p>

<form id="edit-exchange-type" action="" method="post" accept-charset="utf-8">
	<table id='create-exchange' class='vertical'>
		{{ exchange_form }}
		<tr>
			<td>&nbsp;</td>
			<td class='submit'>
				<input type='button' value='Cancel' onclick='history.go(-1)' />
				&nbsp;
				<input type='submit' name='submit-button' value='Save &rarr;' />
			</td>
		</tr>
	</table>
</form>
{% endblock %}
