{% extends "base.html" %}
{% block title %}500 Internal Server Error{% endblock %}
{% block page_header %}500 Internal Server Error{% endblock %}

{% block content %}
<h3>Internal Server Error</h3>

<p>A server error prevented this page from being displayed.  The administrator has been notified and will investigate the problem as soon as possible.</h3>

{% endblock %}