#header-left {
	float: left;
	font-weight: bold;
}

#header-right {
	float: right;
	font-weight: bold;
}

#divider {
	padding: 5px 0;
	border-bottom: 1px solid black;
	clear: both;
}

#client-contact {
	float: left;
}

#report-meta-data {
	float: right;
}

#header {
	padding-top: 10px;
	font-size: 160%;
	font-weight: bold;
	text-align: center;
}

TH {
	text-align: right;
}

TH,TD {
	padding: 2px 10px;
}

.dollars {
	text-align: right;
}
