{% extends "base.html" %}
{% block title %}Remove {{ exchange.type }}{% endblock %}

{% block content %}
	<h2>Remove {{ exchange.type }}</h2>
{% if reconciled %}
	<p>One or more transactions in this exchange have been reconciled.  Please unreconcile them before continuing.</p>
{% else %}
	<p>
		Are you sure you want to remove the {{ exchange.type }} dated 
		{{ exchange.date|date:"l M t, Y" }} with memo "{{ exchange.memo }}"?
	</p>
	<form accept-charset='UTF-8' method='post' action=''>
		<table border='0' cellspacing='0' cellpadding='0' class='spacing'>
			<tr>
				<td class='submit'>
					<input type='button' value='Cancel' onclick='history.go(-1)'/>
					&nbsp;
					<input type='submit' name='submit' value='Remove &rarr;' />
				</td>
			</tr>
		</table>
	</form>
{% endif %}
{% endblock %}
