{% load ledger %}
<table id='recent-exchanges'>
    <caption>Recent Exchanges</caption>
    {% for exchange in recent_exchanges %}
        <tr>
            <td><a href='{% url edit_exchange exchange_id=exchange.id,exchange_type_slug=exchange.type.slug %}'>{{ exchange.id }}</a></td>
            <td>{{ exchange.date|naturalday }}</td>
            <td class='ledger number'>${{ exchange.total|currency }}</td>
            <td>{{ exchange.memo }} <span class='exchange-type'>({{ exchange.type }})</span></td>
        </tr>
    {% endfor %}
</table>