{% load navigation %}
{% extends "base.html" %}
{% block title %}Call Log{% endblock %}

{% block center_column %}
{% for call in calls %}
	{{call.calldate|date:"M j h:i D"}} | {{ call.src }} ( {{call.callerid_name}} ) -> {{ call.dst }}
	<br />
{% endfor %}
{% endblock %}
