<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
	"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
	<meta http-equiv='content-type' content='text/html; charset=iso-8859-1' />
	<title>{% block title %}{% endblock %} | Caktus Consulting Group, LLC</title>
	<link rel="stylesheet" href="/caktus/media/style/report.css" media="screen, print" />
</head>

<body>

<div id="header-left">
Caktus Consulting Group, LLC<br/>
P.O. Box 1454<br/>
Carrboro, NC 27510
</div>
	
<div id="header-right">
Tel: (919) 951-0052
</div>

<div id="divider"></div>

<div id="header">{% block header %}{% endblock %}</div>

<div id="client-contact">
{{ client.name }}<br/>
{% if client.address %}
{{ client.address.street }}<br/>
{{ client.address.city }}, {{ client.address.state }} {{ client.address.zip }}<br/>
{% endif %}
<br/>
ATTN: {% for contact in client.contacts.all %}{{ contact.get_full_name }}{% if not forloop.last %}, {% endif %}{% endfor %}
</div>

{% block meta %}{% endblock %}

<br style="clear: both;"/>
<br/>

{% block content %}{% endblock %}

</body>

</html>
