input.calendar,
select.calendar {
	width: 99px;
}

button.calendar {
	background: url(../images/calendar/calendar-icon.gif);
	border: 0;
	cursor: pointer;
	height: 20px;
	margin-right: 6px;
	width: 20px;
	vertical-align: middle;
}

button.calendar:hover,
button.calendar.active {
	background-position: 0 20px;
}

div.calendar {
	background: url(../images/calendar/calendar.png);
	height: 195px;
	padding: 0 6px;
	text-align: center;
	width: 147px;
}

div.calendar * {
	margin: 0;
	padding: 0;
}

div.calendar div {
	background: none !important;
	cursor: move;
	height: 185px;
	overflow: hidden;
	padding-top: 10px;
	position: relative;
	width: 147px;
}	

div.calendar caption {
	color: #333;
	font: normal 12px/16px Arial, Helvetica, sans-serif;
	padding-top: 6px;
	text-align: center;
	width: 100%;
}

div.calendar caption a {
	cursor: pointer;
	display: block;
	height: 12px;
	overflow: hidden;
	position: absolute;
	text-indent: -100px;
	top: 17px;
	width: 11px;
}

div.calendar caption a.prev {
	background-image: url(../images/calendar/calendar-prev.gif);
	left: 0;
}

div.calendar caption a.next {
	background-image: url(../images/calendar/calendar-next.gif);
	right: 0;
}

div.calendar caption a:hover {
	background-position: 0 12px;
}

div.calendar caption span {
	height: 25px;
	position: relative;
	text-align: center;
}

div.calendar caption span.month {
	padding-right: 8px;
	color: #0597DB;
}

div.calendar caption span.month:after {
	content: ',';
}

div.calendar table {
	background: #FFF;
	border: 0;
	border-collapse: collapse;
	border-spacing: 0;
	cursor: default;
	margin: 0 auto;
	overflow: hidden;
	width: 147px;
}

div.calendar td,
div.calendar th {
	border: 0;
	color: #0597DB;
	font: normal 12px Arial, Helvetica, sans-serif;
	height: 21px;
	text-align: center;
	width: 21px;
}

div.calendar td {
	background: url(../images/calendar/calendar-td.gif);
	color: #FFF;
	font-size: 11px;
}

div.calendar td.invalid {
	color: #999;
}

div.calendar td.valid {
	background: url(../images/calendar/calendar-valid.gif);
	color: #0597DB;
	cursor: pointer;
}

div.calendar td.hilite {
	background: url(../images/calendar/calendar-hilite.gif);
}

div.calendar td.inactive {
	background: url(../images/calendar/calendar-td.gif) 0 100%;
	color: #FFF;
}

div.calendar td.active,
div.calendar td.hover {
	background: url(../images/calendar/calendar-valid.gif) 0 100%;
	color: #FFF;
	cursor: pointer;
}
