/* account ledger style */

body {
	font-size: 7pt;
	font-family: "Lucida Grande", "MS Trebuchet", sans-serif;
}

div#title, div#footer, div#header, div#menu-wrapper,
h2.skinny, ul.header-actions-left {
	display: none;
}

form#date-filter,
ul.date-filters,
div#floating-sidebar {
	display: none;
}

table#ledger_accounts {
	width: 100%;
	margin-left: auto;
	margin-right: auto;
}

td {
	border: 1px solid #eee;
}

a {
  text-decoration: none;
}

TH.ledger {
	font-weight: bold;
	padding: 0.2em;
	margin: 0.3em;
	text-align: center;
}

TH.ledger.account-name {
	padding-top: 2em;
	font-size: 120%;
	text-align: left;
	color: #593E1A;
	border-bottom: 1px solid #593E1A;
}

TH.ledger.memo {
	text-align: left;
}

TH.ledger.date {
	width: 7em;
}

TH.ledger.business {
	width: 15em;
}

TD.ledger.number.total {
	width: 6em;
}

TD.ledger.reconciled {
	padding: 0 0.4em;
	text-align: center;
}

TD.ledger {
	padding: 0.2em;
	margin: 0.3em;
	text-align: left;
}

TH.ledger.number {
	text-align: center;
}

TD.ledger.number {
	text-align: right;
}

TD.ledger:first-child {
}


TH.ledger.account-balance,
TD.ledger.links {
	padding: 0.5em 0.3em 0.2em 0.3em;
}

TD.ledger.links {
	text-align: center;
}

TH.ledger.account-balance {
	text-align: right;
}

TD.ledger.links a {
	text-align: center;
	margin: 0.2em;
}