{% spaceless %}

{% if transaction_form.errors %}
	<td colspan='8'>
		{{ transaction_form.non_field_errors }}
	</td>
</tr>
<tr>
	<td>{{ transaction_form.date.errors }}</td>
	{% if transaction_form.debit %}
		<td>{{ transaction_form.debit.errors }}</td>
	{% endif %}
	{% if transaction_form.credit %}
		<td>{{ transaction_form.credit.errors }}</td>
	{% endif %}
	<td>{{ transaction_form.memo.errors }}</td>
	<td>{{ transaction_form.quantity.errors }}</td>
	<td>{{ transaction_form.amount.errors }}</td>
	<td></td>
	<td></td>
	<td class='hidden'></td>
</tr>
<tr>
{% endif %}

<td class='date'>{{ transaction_form.date|safe }}</td>
{% if transaction_form.debit %}
	<td class='account debit'>{{ transaction_form.debit }}</td>
{% endif %}
{% if transaction_form.credit %}
	<td class='account credit'>{{ transaction_form.credit }}</td>
{% endif %}
<td class='memo'>{{ transaction_form.memo }}</td>
<td class='count'>{{ transaction_form.quantity }}</td>
<td class='rate'>{{ transaction_form.amount }}</td>
<td class='reconciled'>
	{{ transaction_form.credit_reconciled }}/{{ transaction_form.debit_reconciled }}
</td>
<td class='delete'>{{ transaction_form.DELETE }}</td>
<td class='hidden'>{{ transaction_form.id }}</td>

{% endspaceless %}
